@@ -1,14 +1,16 @@
+from __future__ import unicode_literals
 
 from .utils import digattr
 
 from decimal import Decimal
 from datetime import datetime
 
+
 class Field(object):
     type_class = None
 
     def __init__(self, attribute=None, default=None, readonly=False,
-        **kwargs):
+                 **kwargs):
         self.attribute = attribute
         self.default = default
         self.readonly = readonly
@@ -19,6 +21,7 @@ class Field(object):
 
     def reduce(self, value, **kwargs):
         return value
+
     def restore(self, value, **kwargs):
         if self.type_class is not None:
             return self.type_class(value)
@@ -41,63 +44,79 @@ class Field(object):
         except KeyError:
             pass
 
+
 class BooleanField(Field):
     type_class = bool
 
+
 class IntegerField(Field):
     type_class = int
 
+
 class DecimalField(Field):
     type_class = Decimal
+
     def reduce(self, value, **kwargs):
         return float(value)
 
 
 class DateTimeField(Field):
+
     def reduce(self, value, **kwargs):
-        return value.replace(microsecond=0).isoformat(' ')
+        return value.replace(microsecond=0).isoformat(b' ')
+
     def restore(self, value, **kwargs):
         return datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
 
 
 class DateField(Field):
+
     def reduce(self, value, **kwargs):
         return value.isoformat()
+
     def restore(self, value, **kwargs):
         return datetime.strptime(value, '%Y-%m-%d').date()
 
 
 class TimeField(Field):
+
     def reduce(self, value, **kwargs):
         return value.isoformat()
+
     def restore(self, value, **kwargs):
         return datetime.strptime(value, '%H:%M:%S').time()
 
 
 class SerialiserField(Field):
-    def __init__(self, **kwargs):
-        super(SerialiserField, self).__init__(**kwargs)
+
+    def __init__(self, *args, **kwargs):
+        super(SerialiserField, self).__init__(*args, **kwargs)
         self.serialiser = kwargs['serialiser']
 
     def reduce(self, value, **kwargs):
         return self.serialiser.object_deflate(value)
+
     def restore(self, value, **kwargs):
         return self.serialiser.object_inflate(value)
 
 
 class ManySerialiserField(Field):
+
     def __init__(self, *args, **kwargs):
         super(ManySerialiserField, self).__init__(*args, **kwargs)
         self.serialiser = kwargs['serialiser']
 
     def reduce(self, value, **kwargs):
         return self.serialiser.list_deflate(iter(value), **kwargs)
+
     def restore(self, value, **kwargs):
         return self.serialiser.list_inflate(value, **kwargs)
 
 
 class FileField(Field):
+
     def reduce(self, value, **kwargs):
         return value.url
+
     def restore(self, value, **kwargs):
         pass
