@@ -1,9 +1,11 @@
+from __future__ import unicode_literals
 
-from . import fields
-from .meta import Meta
+from . import fields, http
 from .serialiser import MetaSerialiser, Serialiser
 from .publisher import Publisher
 
+from six import with_metaclass
+
 from django.shortcuts import get_object_or_404
 
 FIELD_MAP = {}
@@ -27,8 +29,12 @@ class MetaModelSerialiser(MetaSerialiser):
 
         current_fields = new_class._fields.keys()
 
+        model_fields = {}
         try:
             model = new_class._meta.model
+        except AttributeError:
+            pass
+        else:
             for f in model._meta.fields:
                 # If we've got one, skip...
                 if f.name in current_fields:
@@ -48,15 +54,14 @@ class MetaModelSerialiser(MetaSerialiser):
                 }
 
                 field_class = FIELD_MAP.get(f.__class__.__name__, fields.Field)
-                new_class._fields[f.name] = field_class(**kwargs)
-        except AttributeError:
-            pass
+                model_fields[f.name ] = field_class(**kwargs)
+
+        new_class._fields.update(model_fields)
 
         return new_class
 
 
-class ModelSerialiser(Serialiser):
-    __metaclass__ = MetaModelSerialiser
+class ModelSerialiser(with_metaclass(MetaModelSerialiser,Serialiser)):
 
     def restore_object(self, obj, instance, **kwargs):
         if instance:
@@ -167,18 +172,25 @@ def modelserialiser_factory(name, model, **kwargs):
     except KeyError:
         pass
 
+    try:
+        attrs['read_only'] = kwargs['read_only']
+    except KeyError:
+        pass
+
     meta = type('Meta', (object,), attrs)
     return type(ModelSerialiser)(name, (ModelSerialiser,), {'Meta': meta})
 
 class ModelSerialiserField(fields.SerialiserField):
-    def __init__(self, serialiser=None, model=None, *args, **kwargs):
-        if serialiser is None:
-            serialiser = modelserialiser_factory(model.__name__ + 'Serialiser', model, **kwargs)()
-        super(ModelSerialiserField, self).__init__(serialiser, *args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        if not 'serialiser' in kwargs:
+            model = kwargs.pop('model')
+            kwargs['serialiser'] = modelserialiser_factory(model.__name__ + 'Serialiser', model, **kwargs)()
+        super(ModelSerialiserField, self).__init__(*args, **kwargs)
 
 class ModelManySerialiserField(fields.ManySerialiserField):
-    def __init__(self, serialiser=None, model=None, *args, **kwargs):
-        if serialiser is None:
-            serialiser = modelserialiser_factory(model.__name__ + 'Serialiser', model, **kwargs)()
-        super(ModelManySerialiserField, self).__init__(serialiser, *args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        if not 'serialiser' in kwargs:
+            model = kwargs.pop('model')
+            kwargs['serialiser'] = modelserialiser_factory(model.__name__ + 'Serialiser', model, **kwargs)()
+        super(ModelManySerialiserField, self).__init__(*args, **kwargs)
 
