@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 # Put this on module path in file newrelic_django_nap.py.
 #
 # In agent configuration file add:
@@ -5,7 +7,6 @@
 # [import-hook:nap.publisher]
 # enabled = true
 # execute = nap.newrelic:instrument_django_nap_publisher
-from __future__ import absolute_import
 
 from newrelic.agent import (current_transaction, set_transaction_name,
     FunctionTrace, callable_name, ObjectWrapper)
