@@ -1,5 +1,6 @@
+from __future__ import unicode_literals
 
-from django.conf.urls import url, patterns, include
+from django.conf.urls import url
 from django.core.paginator import Paginator, EmptyPage
 from django.utils.decorators import method_decorator
 from django.views.decorators.http import require_http_methods
@@ -124,7 +125,7 @@ class BasePublisher(object):
             'object': object_handlers,
         }
 
-            
+
 class Publisher(engine.JsonEngine, BasePublisher):
     '''Default API-style publisher'''
     LIMIT_PARAM = 'limit'
